/* this next is not necessary for Borland C, but is for Sun Unix: */ 
extern long timezone;

/* ----------------------------------------------------------------
 * noargs returns the double-float julian day number for the current local time
 * inputs
 *    none
 *    unless you count global variables gregorian and jdtransition
 * outputs
 *    double-float julian day number
 * side effects
 *    prints julian day number, and local and GMT 
 *    calls setGregorian() 
 * required header files
 *    jd.h
 *
 * the routines called are documented in the Borland C manuals;
 * and possibly in the C manuals of other compilers.
 * they follow approximately the UNIX conventions.
 */


double  
noargs()
{
	char *date_string;	/* date and time, as a character string */ 
	double xjd;		/* julian day corresponding to GMT */
	double xljd;		/* julian day corresponding to local time */
	long utime;		/* seconds since 1970.0 */
	char *gmt_string;	/* a date string for GMT */
	struct tm *gmt;		/* time-structure (see time.h) for GMT */
	char *now;		/* should be local date and time */ 
	struct tm *nowtime;	/* a pointer of convience */ 
	static char *tzstr;	/* for environment call */
	
	time_t t;
	struct tm *local, *gm;

	static char buf[80];	/* used to hold strings for printed output */
	char *format;		/* used to format printed output */
	int isdst;		/* are we on daylight savings time? 1=yes, 0=no */

	/* ---------------------------------------------------------------- */
	tzstr = "TZ=EST5EDT";
	/*	putenv(tzstr); */	/* this fixes the program for Eastern time */ 
	tzset();
	/* timezone = 5 * 3600; */

	time( &utime ); 
	/* jd 2440587.5 is 1970.0, the start of the unix clock */
	xjd = 2440587.5 + utime/86400.; 

	printf(" julian day number for GMT = %10.3f \n", xjd );

/* the old way won't get julian calendar dates correctly;
 *  it does work quite satisfactorily for gregorian calendar dates:
 */ 
#ifdef obsolete
	t = time(NULL);
	local = localtime( &t ); 
	gm    = gmtime( &t );
	printf(" pdt: %s", asctime( local ) ); 
	printf(" gmt: %s", asctime( gm ) );
#endif obsolete 

	/* determine the daylight savings time correction: */ 
	t = time(NULL);
	local = localtime( &t ); 
	isdst = local->tm_isdst; 
	if (isdst)	/* correct from GMT to . . . */ 
	  xljd = xjd - ((timezone/3600.) -1.)/24.;	/* local daylight time */
	else
	  xljd = xjd - (timezone/3600.)/24.;		/* local standard time */
	   
	/* find out which calendar we are on: */ 
	setGregorian( jdnoon( xjd ) ); 

	/* print the date and time, GMT and local, accordingly: */ 
	format = "%d-%d-%d %d:%d:%d"; 
	if (gregorian)
	{
	  printf(" gmt  : % 8s\n", xGregorianCalendarDate( xjd, buf, format ) );
	  printf(" local: % 8s\n", xGregorianCalendarDate( xljd, buf, format ) );
	}
	else
	{
	  printf(" gmt  : % 8s\n", xJulianCalendarDate( xjd, buf, format )    );
	  printf(" local: % 8s\n", xJulianCalendarDate( xljd, buf, format )    );
	}
	return xjd; 

}



/* ----------------------------------------------------------------
 * jdnow returns the double-float julian day number for the current local time
 * inputs
 *    none
 * outputs
 *    double-float julian day number
 * side effects
 *    none
 * required header files
 *    jd.h
 *
 * the routines called are documented in the Borland C manuals;
 * and possibly in the C manuals of other compilers.
 * they follow approximately the UNIX conventions.
 */



double  
jdnow()
{
	double xjd;		/* julian day */
	long utime;		/* seconds since 1970.0 */
	time_t t;		/* see Borland Manual, at localtime()  */ 
	struct tm *local;	/* see Borland Manual, at localtime()  */ 
	int isdst;		/* whether we are currently on daylight savings time */ 
	long jd; 

	tzset();	 /* see Borland C manual, p. 534; this presumes <set TZ=PDT8PST> has set the environment */ 

	/* time() gets seconds since 1970.0 GMT; see Borland manual at time()  
	 * I don't know whether it corrects for leap-seconds; presumably not;
	 * as of 1993, there are about 30 of them
	 * see NASA NAIF-spice-lib file leapseco.ker or some such name.
	 */
	time( &utime ); 

	/* jd 2440587.5 is 1970.0, i. e., midnight 1969-12-31/1970-1-1,
	 * the start of the unix clock
	 */
	xjd = 2440587.5 + utime/86400.; 

	/* to find out whether we are on daylight savings time: */ 
	t = time(NULL);
	local = localtime( &t ); 
	isdst = local->tm_isdst; 

	if (isdst)	/* correct from GMT to . . . */ 
	  xjd -= ((timezone/3600.) -1.)/24.;	/* local daylight time */
	else
	  xjd -= (timezone/3600.)/24.;		/* local standard time */
	  
	jd = jdnoon( xjd ); 
	setGregorian( jd ); 

	return xjd; 
}
